@@ -359,6 +359,12 @@ class H323Codec : public PObject
     */
     void CalculateRTPSendTime(DWORD timeStamp, unsigned rate, PInt64 & sendTime) const;
 
+   /**Get RTP session ID
+    */
+    int GetRTPSessionID() const { return rtpInformation.m_sessionID; }
+
+    H323Channel * GetLogicalChannel() { return logicalChannel; }
+
   protected:
     Direction direction;
     OpalMediaFormat mediaFormat;
