@@ -189,7 +189,7 @@ public:
       */
     PBoolean DecodeMediaKey(PBYTEArray & key);
 
-    /** Is Active 
+    /** Is Active
       */
     PBoolean IsActive();
 
@@ -216,6 +216,10 @@ public:
 
     PString GetAlgorithmOID() const { return m_context.GetAlgorithmOID(); }
 
+    /** Export crypto key for signaling-only gateways
+	  */
+	PBYTEArray GetCrytoMasterKey() const { return m_crytoMasterKey; }
+
 private:
     H235_DiffieHellman & m_dh;
     H235CryptoEngine     m_context;        /// Media encryption
