@@ -71,6 +71,12 @@ class H450ServiceAPDU : public X880_ROS
                                 const PString & callIdentity);
 
     void BuildCallWaiting(int invokeId, int numCallsWaiting);
+
+    X880_Invoke & BuildMessageWaitIndicationActivate(int invokeId);
+    X880_Invoke & BuildMessageWaitIndicationDeactivate(int invokeId);
+    X880_Invoke & BuildMessageWaitIndicationInterrogate(int invokeId);
+
+    X880_ReturnResult & BuildMessageWaitIndicationResult(int invokeId, int opcode);
     
     void BuildCallIntrusionForcedRelease(int invokeId, int CICL);
     X880_ReturnResult& BuildCallIntrusionForcedReleaseResult(int invokeId);
@@ -668,6 +674,88 @@ class H4506Handler : public H450xHandler
 };
 
 
+class H4507Handler : public H450xHandler
+{
+    PCLASSINFO(H4507Handler, H450xHandler);
+  public:
+    H4507Handler(
+      H323Connection & connection,
+      H450xDispatcher & dispatcher
+    );
+
+    virtual void AttachToSetup(
+      H323SignalPDU & pdu
+    );
+
+    virtual void AttachToConnect(
+      H323SignalPDU & pdu
+    );
+
+    virtual PBoolean OnReceivedInvoke(
+      int opcode,
+      int invokeId,                           ///<  InvokeId of operation (used in response)
+      int linkedId,                           ///<  InvokeId of associated operation (if any)
+      PASN_OctetString * argument             ///<  Parameters for the initiate operation
+    );
+
+    PBoolean OnReceiveMWIActivate(
+      PASN_OctetString * argument ///<  Parameters for the initiate operation
+    );
+ 
+    PBoolean OnReceiveMWIDeactivate(
+      PASN_OctetString * argument ///<  Parameters for the initiate operation
+    );
+
+    PBoolean OnReceiveMWIInterrogate(
+      PASN_OctetString * argument ///<  Parameters for the initiate operation
+    );
+
+    PBoolean OnReceiveMWIInterrogateResult(
+      PASN_OctetString * argument ///<  Parameters for the initiate operation
+    );
+
+    virtual PBoolean OnReceivedReturnResult(
+      X880_ReturnResult & returnResult
+    );
+
+    virtual PBoolean OnReceivedReturnError(
+      int errorCode,
+      X880_ReturnError & returnError
+    );
+
+    enum State {
+      e_mwi_Idle,
+      e_mwi_Wait
+    };
+ 
+    State GetState() const { return mwiState; }
+
+    enum Type {
+      e_mwi_typeNone,
+      e_mwi_activate,
+      e_mwi_deactivate,
+      e_mwi_interrogate,
+    };
+ 
+    Type GetType() const { return mwiType; }
+
+    void StartmwiTimer(const PTimeInterval value) { mwiTimer = value; }
+
+    void StopmwiTimer();
+
+    PBoolean IsmwiTimerRunning() { return mwiTimer.IsRunning(); }
+
+
+    PDECLARE_NOTIFIER(PTimer, H4507Handler, OnMWITimeOut);
+
+  protected:
+    State       mwiState;               // Call state of this connection
+    Type        mwiType;                // Type of MWI action
+    PTimer      mwiTimer;               // Timer - T1 and T2
+
+};
+
+
 class H45011Handler : public H450xHandler
 {
   PCLASSINFO(H45011Handler, H450xHandler);
